pub struct DigestReport {
pub sha1_header: DigestStatus,
pub sha256_header: DigestStatus,
pub sha3_256_header: DigestStatus,
pub payload_sha256: DigestStatus,
pub payload_sha512: DigestStatus,
pub payload_sha3_256: DigestStatus,
}Expand description
Results of verifying all digests in the package.
Each field represents a specific digest type. Not all digests are present in all packages — v4 packages typically have MD5, SHA1, and SHA256, while v6 packages add SHA3-256 and SHA-512 variants.
Fields
sha1_header: DigestStatusSHA-1 of the header (signature header, v4 packages).
sha256_header: DigestStatusSHA-256 of the header (signature header).
sha3_256_header: DigestStatusSHA3-256 of the header (signature header, v6 packages).
payload_sha256: DigestStatusSHA-256 of the compressed payload.
payload_sha512: DigestStatusSHA-512 of the compressed payload (v6 packages).
payload_sha3_256: DigestStatusSHA3-256 of the compressed payload (v6 packages).
Implementations
Sourceimpl DigestReport
impl DigestReport
Sourcepub fn has_header_digest(&self) -> bool
pub fn has_header_digest(&self) -> bool
Returns true if at least one header digest was present.
Sourcepub fn has_payload_digest(&self) -> bool
pub fn has_payload_digest(&self) -> bool
Returns true if at least one payload digest was present.