RPMPackage

Struct RPMPackage 

pub struct RPMPackage {
    pub metadata: RPMPackageMetadata,
    pub content: Vec<u8>,
}
A complete rpm file.

Can either be created using the RPMPackageBuilder or used with parse to obtain from a file.

Fields

metadata: RPMPackageMetadata

Header and metadata structures.

Contains the constant lead as well as the metadata store.

content: Vec<u8>

The compressed or uncompressed files.

Implementations

Source

impl RPMPackage

pub async fn parse_async<I: AsyncRead + Unpin>( input: &mut I, ) -> Result<Self, RPMError>

pub fn parse<T: BufRead>(input: &mut T) -> Result<Self, RPMError>

pub fn write<W: Write>(&self, out: &mut W) -> Result<(), RPMError>

pub async fn write_async<W: AsyncWrite + Unpin>( &self, out: &mut W, ) -> Result<(), RPMError>

pub fn sign<S>(&mut self, signer: S) -> Result<(), RPMError>
where S: Signing<RSA, Signature = Vec<u8>>,

sign all headers (except for the lead) using an external key and store it as the initial header

pub fn verify_signature<V>(&self, verifier: V) -> Result<(), RPMError>
where V: Verifying<RSA, Signature = Vec<u8>>,

Verify the signature as present within the RPM package.