pub struct RPMPackage {
pub metadata: RPMPackageMetadata,
pub content: Vec<u8>,
}Expand description
A complete rpm file.
Can either be created using the RPMPackageBuilder
or used with parse to obtain from a file.
Fields
metadata: RPMPackageMetadataHeader and metadata structures.
Contains the constant lead as well as the metadata store.
content: Vec<u8>The compressed or uncompressed files.
Implementations
Sourceimpl RPMPackage
impl RPMPackage
pub async fn parse_async<I: AsyncRead + Unpin>( input: &mut I, ) -> Result<Self, RPMError>
pub fn parse<T: BufRead>(input: &mut T) -> Result<Self, RPMError>
pub fn write<W: Write>(&self, out: &mut W) -> Result<(), RPMError>
pub async fn write_async<W: AsyncWrite + Unpin>( &self, out: &mut W, ) -> Result<(), RPMError>